@@ -1,4 +1,4 @@
-// $Id: bruby.cpp,v 1.8 2003/01/16 09:33:39 yuya Exp $
+// $Id: bruby.cpp,v 1.9 2003/01/23 17:17:10 yuya Exp $
 
 #include "BRbBase.h"
 #include "BRb.h"
@@ -8,10 +8,12 @@
 #ifdef BRB_WRITER
 static VALUE rb_brb_s_dump(VALUE obj, VALUE source, VALUE filename);
 static VALUE rb_brb_s_dumpfile(VALUE obj, VALUE filename);
+static VALUE rb_brb_s_dumpproc(VALUE obj, VALUE proc);
 #endif
 #ifdef BRB_READER
-static VALUE rb_brb_s_load(VALUE obj, VALUE bytecode);
+static VALUE rb_brb_s_load(VALUE obj, VALUE code);
 static VALUE rb_brb_s_loadfile(VALUE obj, VALUE filename);
+static VALUE rb_brb_s_loadproc(VALUE obj, VALUE code);
 #endif
 #if defined(BRB_WRITER) && defined(BRB_READER)
 static VALUE rb_brb_s_verify(VALUE obj, VALUE source, VALUE filename);
@@ -48,15 +50,26 @@ rb_brb_s_dumpfile(VALUE obj, VALUE filename)
 	return BRb::dumpfile(filename, g_debug, rb_eBRbException);
 }
 
+static VALUE
+rb_brb_s_dumpproc(VALUE obj, VALUE proc)
+{
+	Check_Type(proc, T_DATA);
+
+	struct BLOCK *data;
+	Data_Get_Struct(proc, struct BLOCK, data);
+
+	return Qnil;
+}
+
 #endif
 
 #ifdef BRB_READER
 
 static VALUE
-rb_brb_s_load(VALUE obj, VALUE bytecode)
+rb_brb_s_load(VALUE obj, VALUE code)
 {
-	Check_Type(bytecode, T_STRING);
-	return BRb::loadcode(bytecode, ::rb_str_new2("(bruby)"), g_debug, rb_eBRbException);
+	Check_Type(code, T_STRING);
+	return BRb::loadcode(code, ::rb_str_new2("(bruby)"), g_debug, rb_eBRbException);
 }
 
 static VALUE
@@ -66,6 +79,12 @@ rb_brb_s_loadfile(VALUE obj, VALUE filename)
 	return BRb::loadfile(filename, g_debug, rb_eBRbException);
 }
 
+static VALUE
+rb_brb_s_loadproc(VALUE obj, VALUE code)
+{
+	return Qnil;
+}
+
 #endif
 
 #if defined(BRB_WRITER) && defined(BRB_READER)
@@ -110,10 +129,12 @@ Init_bruby()
 #ifdef BRB_WRITER
 	::rb_define_singleton_method(rb_mBRb, "dump",       (VALUE(*)(...))rb_brb_s_dump,       2);
 	::rb_define_singleton_method(rb_mBRb, "dumpfile",   (VALUE(*)(...))rb_brb_s_dumpfile,   1);
+	::rb_define_singleton_method(rb_mBRb, "dumpproc",   (VALUE(*)(...))rb_brb_s_dumpproc,   1);
 #endif
 #ifdef BRB_READER
 	::rb_define_singleton_method(rb_mBRb, "load",       (VALUE(*)(...))rb_brb_s_load,       1);
 	::rb_define_singleton_method(rb_mBRb, "loadfile",   (VALUE(*)(...))rb_brb_s_loadfile,   1);
+	::rb_define_singleton_method(rb_mBRb, "loadproc",   (VALUE(*)(...))rb_brb_s_loadproc,   1);
 #endif
 #if defined(BRB_WRITER) && defined(BRB_READER)
 	::rb_define_singleton_method(rb_mBRb, "verify",     (VALUE(*)(...))rb_brb_s_verify,     2);
